Cookie Policy | webretro

Privacy Policy Terms and Conditions

# Cookie policy

This cookie policy ("Policy") describes what cookies are and how and they're being used by the binbashbanana.github.io/webretro website ("Website" or "Service") and any of its related products and services (collectively, "Services"). This Policy is a legally binding agreement between you ("User", "you" or "your") and this Website operator ("Operator", "we", "us" or "our"). You should read this Policy so you can understand the types of cookies we use, the information we collect using cookies and how that information is used. It also describes the choices available to you regarding accepting or declining the use of cookies. For further information on how we use, store and keep your personal data secure, see our privacy policy.

## What are cookies?

Cookies are small pieces of data stored in text files that are saved on your computer or other devices when websites are loaded in a browser. They are widely used to remember you and your preferences, either for a single visit (through a "session cookie") or for multiple repeat visits (using a "persistent cookie").

Session cookies are temporary cookies that are used during the course of your visit to the Website, and they expire when you close the web browser.

Persistent cookies are used to remember your preferences within our Website and remain on your desktop or mobile device even after you close your browser or restart your computer. They ensure a consistent and efficient experience for you while visiting the Website and Services.

Cookies may be set by the Website ("first-party cookies"), or by third parties, such as those who serve content or provide advertising or analytics services on the Website ("third party cookies"). These third parties can recognize you when you visit our website and also when you visit certain other websites. Click here to learn more about cookies and how they work.

## What type of cookies do we use?

### Functionality cookies

Functionality cookies let us operate the Website and Services in accordance with the choices you make. Your game progress will be saved to these cookies.

## What are your cookie options?

If you don't like the idea of cookies, you can leave this site and not come back until you are ready to accept cookies.

## Changes and amendments

We reserve the right to modify this Policy or its terms relating to the Website and Services at any time, effective upon posting of an updated version of this Policy on the Website. When we do, we will revise the updated date at the bottom of this page. Continued use of the Website and Services after any such changes shall constitute your consent to such changes.

## Acceptance of this policy

You acknowledge that you have read this Policy and agree to all its terms and conditions. By accessing and using the Website and Services you agree to be bound by this Policy. If you do not agree to abide by the terms of this Policy, you are not authorized to access or use the Website and Services. This cookie policy was created with the cookie policy generator.

## Contacting us

If you would like to contact us to understand more about this Policy or wish to contact us concerning any matter relating to our use of cookies, you may message me on discord: OlyB#9420.

This document was last updated on April 24, 2021